@@ -23,6 +23,7 @@ __copyright__ = 'Copyright 2013 Fred Wang'
 import json
 import time
 import hmac
+import math
 import requests
 import logging
 from datetime import datetime
@@ -91,14 +92,22 @@ class BaseAPIRequest(object):
         ts_start = time.time()
         data, files = self.sign()
         ret = {}
-        for try_id in xrange(self.client.retry_count, 0, -1):
+        retry_count = self.client.retry_count
+        for try_id in xrange(retry_count):
             ret = self.open(data, files)
             for file in files.values():
                 file.seek(0)
-            if 'error_response' in ret and ret['error_response'].get('sub_code') in self.retry_sub_codes:
-                continue
-            else:
-                break
+            if 'error_response' in ret:
+                sub_code = ret['error_response'].get('sub_code')
+                if sub_code in self.retry_sub_codes:
+                    continue
+                elif sub_code == 'accesscontrol.limited-by-api-access-count':
+                    if try_id < retry_count - 1:
+                        ts_sleep = 0.1 * math.pow(2, try_id)
+                        time.sleep(ts_sleep)
+                        logging.warn("meet access-control, sleep %.3lf seconds", ts_sleep)
+                    continue
+            break
         ts_used = (time.time() - ts_start) * 1000
         files2 = dict([(k, str(v)) for k, v in files.items()])
         data.update(**files2)
@@ -190,7 +199,7 @@ class TaoBaoAPIClient(object):
     """API client using synchronized invocation."""
 
     def __init__(self, app_key, app_secret, domain='gw.api.taobao.com', fetcher_class=DefaultAPIRequest,
-                 retry_sub_codes=None, retry_count=3, **kw):
+                 retry_sub_codes=None, retry_count=5, **kw):
         """Init API Client"""
         self.client_id = app_key
         self.client_secret = app_secret
